Boa Restrictor Linter
=====================

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   features/configuration.md
   features/rules.md
   features/changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
